Module events

Module events 

Structs

Properties
Generic properties that can be attached to any element
Style
Visual style properties

Enums

Direction
Direction for layouts
EdgeType
Types of edges/connections
EventResult
Result of processing an event
GraphEvent
Rich graph events that can represent any type of diagram
GroupType
Group types
LayoutType
Layout hints for visualization
MessageType
Message types for sequence diagrams
NodeType
Types of nodes - generic enough for any diagram
Position
Position hints
StateType
State types for state machines