Structs
- Properties
- Generic properties that can be attached to any element
- Style
- Visual style properties
Enums
- Direction
- Direction for layouts
- Edge
Type - Types of edges/connections
- Event
Result - Result of processing an event
- Graph
Event - Rich graph events that can represent any type of diagram
- Group
Type - Group types
- Layout
Type - Layout hints for visualization
- Message
Type - Message types for sequence diagrams
- Node
Type - Types of nodes - generic enough for any diagram
- Position
- Position hints
- State
Type - State types for state machines